@@ -1,6 +1,8 @@
 import os
 import io
 from typing import Union
+import json
+from errors.error import FolderNotFound, NotStringOrBytes
 
 
 class FileHandler:
@@ -40,7 +42,7 @@ class FileHandler:
             with open(self._filename, 'w') as f:
                 f.write(new_content)
         else:
-            raise TypeError('Content must be string or bytes type object')
+            raise NotStringOrBytes()
 
     def add_something_to_file_content(self, content: Union[str, bytes]) -> None:
         """Appends content to end of the file!"""
@@ -51,7 +53,7 @@ class FileHandler:
             with open(self._filename, 'a') as f:
                 f.write(content)
         else:
-            raise TypeError('Content must be string or bytes type object')
+            raise NotStringOrBytes()
 
     def what_type_of_file(self) -> str:
         """Tells you what type of file is it."""
@@ -82,7 +84,31 @@ class FileHandler:
                 return True
             else:
                 return False
+
+
+class JsonHandler:
+    """JsonHandler it reads, converts and writes but remeber file should be json only!"""
+    def __init__(self, _filename):
+        self._filename = _filename
     
+    def write_to_json(self, obj: Union[dict, list]) -> None:
+        """Writes to json file"""
+        with open(self._filename, 'w') as f:
+            json.dump(obj, f)
+
+    def append_to_json(self, obj: Union[dict, list]) -> None:
+        """Writes to json file"""
+        with open(self._filename, 'a') as f:
+            json.dump(obj, f)
+
+    def read_json_file(self) -> Union[dict, list]:
+        with open(self._filename, 'r') as f:
+            x = json.load(f)
+            return x
+    
+
+
+
     
 
 
@@ -115,7 +141,7 @@ def list_item_in_dir(path) -> list:
     if os.path.exists(path):
         return os.listdir(path)
     else:
-        raise FileNotFoundError('Folder Not Found!')
+        raise FolderNotFound()
 
 
 def delete_all_item_in_dict(path: str) -> list:
@@ -127,7 +153,7 @@ def delete_all_item_in_dict(path: str) -> list:
             em.append(i)
         return em
     else:
-        raise FileNotFoundError('Folder not found or wrong path.')
+        raise FolderNotFound()
 
 
 def is_pythonfile(file: str) -> bool:
